Copying Git-ignored local files into newly created worktrees (spec 8).
On new/pr, files in the source worktree matching the configured copy
glob patterns are copied into the new worktree, except: tracked files (they
come from the checkout) and files that already exist in the target (never
overwritten). The .git directory is never traversed.
Structs
- Copy
Outcome - The outcome of a copy step.
Functions
- copy_
ignored_ files - Copies ignored files matching
patternsfromsourceintotarget(spec 8). Tracked files and existing targets are skipped.