Module types

Module types 

gh JSON shapes and their mapping to the domain model (spec 4).

Structs

Author
A PR author ({ "login": ... }).
OpenPr
An open PR found for a branch, as returned by gh pr list --head <branch> --json number,url,state,isDraft.
PrSummary
A PR as returned by gh pr list --json ....
PrView
A PR as returned by gh pr view <target> --json ....

Functions

pr_state
Maps a gh state string + draft flag to a PrState.